@@ -359,8 +359,8 @@ void HandleFocusIn()
       else
 	{
 	  SetBorder(Scr.Hilite,False,True,True,None);
-	  Broadcast(M_FOCUS_CHANGE,5,0,0,0,Scr.HiColors.fore,
-		    Scr.HiColors.back,0,0);
+	  Broadcast(M_FOCUS_CHANGE,5,0,0,0,Scr.ActiveTitleColors.fore,
+		    Scr.ActiveTitleColors.back,0,0);
 	  if (Scr.ColormapFocus == COLORMAP_FOLLOWS_FOCUS)
 	    {
 	      if((Scr.Hilite)&&(!(Scr.Hilite->flags & ICONIFIED)))
@@ -379,8 +379,8 @@ void HandleFocusIn()
     {
       SetBorder(Tmp_win,True,True,True,None);
       Broadcast(M_FOCUS_CHANGE,5,Tmp_win->w,
-		Tmp_win->frame,(unsigned long)Tmp_win,Scr.HiColors.fore,
-		Scr.HiColors.back,0,0);
+		Tmp_win->frame,(unsigned long)Tmp_win,Scr.ActiveTitleColors.fore,
+		Scr.ActiveTitleColors.back,0,0);
       if (Scr.ColormapFocus == COLORMAP_FOLLOWS_FOCUS)
 	{
 	  if((Scr.Hilite)&&(!(Scr.Hilite->flags & ICONIFIED)))
@@ -572,12 +572,12 @@ void HandlePropertyNotify()
 	    }
 	}
       break;
-      
+
     case XA_WM_NORMAL_HINTS:
       {
 	int new_width, new_height;
 	
-	GetWindowSizeHints (Tmp_win);
+	GetWindowSizeHints(Tmp_win);
 	new_width = Tmp_win->frame_width;
 	new_height = Tmp_win->frame_height;
 	ConstrainSize(Tmp_win, &new_width, &new_height);
@@ -589,24 +589,24 @@ void HandlePropertyNotify()
 	BroadcastConfig(M_CONFIGURE_WINDOW,Tmp_win);
       }
       break;
-      
+
     default:
-      if(Event.xproperty.atom == _XA_WM_PROTOCOLS)
-	FetchWmProtocols (Tmp_win);
+      if (Event.xproperty.atom == _XA_WM_PROTOCOLS)
+        FetchWmProtocols(Tmp_win);
       else if (Event.xproperty.atom == _XA_WM_COLORMAP_WINDOWS)
-	{
-	  FetchWmColormapWindows (Tmp_win);	/* frees old data */
-	  ReInstallActiveColormap();
-	}
-      else if(Event.xproperty.atom == _XA_WM_STATE)
-	{
-	  if((Tmp_win != NULL)&&(Tmp_win->flags & ClickToFocus)
-	     &&(Tmp_win == Scr.Focus))
-	    {
+        {
+          FetchWmColormapWindows(Tmp_win);   /* frees old data */
+          ReInstallActiveColormap();
+        }
+      else if (Event.xproperty.atom == _XA_WM_STATE)
+        {
+          if ((Tmp_win != NULL) && (Tmp_win->flags & ClickToFocus)
+            &&(Tmp_win == Scr.Focus))
+            {
 	      Scr.Focus = NULL;
-	      SetFocus(Tmp_win->w,Tmp_win,0);
+	      SetFocus(Tmp_win->w, Tmp_win, 0);
 	    }
-	}
+        }
       break;
     }
 }
@@ -708,9 +708,7 @@ void HandleMapRequestKeepRaised(Window KeepRaised)
   extern long isIconicState;
   extern Bool PPosOverride;
   
-  Event.xany.window = Event.xmaprequest.window;
-  
-  if(XFindContext(dpy, Event.xany.window, FvwmContext, 
+  if(XFindContext(dpy, Event.xmaprequest.window, FvwmContext, 
 		  (caddr_t *)&Tmp_win)==XCNOENT)
     Tmp_win = NULL;
   
@@ -721,13 +719,14 @@ void HandleMapRequestKeepRaised(Window KeepRaised)
   if(!Tmp_win)
     {
       /* Add decorations. */
-      Tmp_win = AddWindow(Event.xany.window);
+      Tmp_win = AddWindow(Event.xmaprequest.window);
       if (Tmp_win == NULL)
 	return;
     }
 
   if(KeepRaised != None)
-    XRaiseWindow(dpy,KeepRaised);
+    XRaiseWindow(dpy, KeepRaised);
+
   /* If it's not merely iconified, and we have hints, use them. */
   if (!(Tmp_win->flags & ICONIFIED))
     {
@@ -924,13 +923,15 @@ void HandleUnmapNotify()
     }
   
   XGrabServer(dpy);
-  
+
+/*
   if(XCheckTypedWindowEvent (dpy, Event.xunmap.window, DestroyNotify,&dummy)) 
     {
       Destroy(Tmp_win);
       XUngrabServer (dpy);
       return;
     } 
+*/
 
   /*
    * The program may have unmapped the client window, from either
@@ -1126,14 +1127,8 @@ void HandleEnterNotify()
     return;
   
   if(!(Tmp_win->flags & ClickToFocus))
-    {
-      if(Scr.Focus != Tmp_win)
-	{
-	  SetFocus(Tmp_win->w,Tmp_win,1);
-	}
-      else
-	SetFocus(Tmp_win->w,Tmp_win,1);
-    }
+    SetFocus(Tmp_win->w,Tmp_win,1);
+
   if (Scr.ColormapFocus == COLORMAP_FOLLOWS_MOUSE)
   {
     if((!(Tmp_win->flags & ICONIFIED))&&(Event.xany.window == Tmp_win->w))
