@@ -97,6 +97,10 @@ typedef struct MenuRoot
     int func;
     int x, y;
     Bool has_coords;		/* true if x and y are valid */
+    Picture *sidePic;
+    Pixel sideColor;
+    Bool colorize;
+    short xoffset;
 } MenuRoot;
 
 typedef struct Binding
