@@ -1,5 +1,4 @@
-#include "../configure.h"
-#include <string.h>
+#include <FVWMconfig.h>
 
 #if HAVE_UNAME
 /* define mygethostname() by using uname() */
