@@ -1,7 +1,7 @@
-/* -*-c-*- */
-#include <libs/fvwmlib.h>
-#include <fvwm/fvwm.h>
-#include <libs/vpacket.h>
+#include <fvwm/fvwmlib.h>
+
+#define STICKY 1
+#define ICONIFIED     32 /* is it an icon now? */
 
 struct list
 {
@@ -16,23 +16,32 @@ struct list
   int frame_y;
   int title_height;
   int boundary_width;
-  window_flags flags;
+  unsigned long flags;
   unsigned long gravity;
   long desk;
   struct list *next;
-  char *name;
 };
 
-/*
+/*************************************************************************
  *
  * Subroutine Prototypes
- *
- */
+ * 
+ *************************************************************************/
 void Loop(int *fd);
+void SendInfo(int *fd,char *message,unsigned long window);
+char *safemalloc(int length);
 struct list *find_window(unsigned long id);
 void add_window(unsigned long new_win, unsigned long *body);
-RETSIGTYPE DeadPipe(int nonsense);
+void DeadPipe(int nonsense);
 void process_message(unsigned long type,unsigned long *body);
 void do_save(void);
 void list_new_page(unsigned long *body);
 
+#ifdef BROKEN_SUN_HEADERS
+#include "../../fvwm/sun_headers.h"
+#endif
+
+
+#ifdef NEEDS_ALPHA_HEADER
+#include "../../fvwm/alpha_header.h"
+#endif /* NEEDS_ALPHA_HEADER */
