@@ -131,7 +131,7 @@ void main(int argc, char **argv)
     {
       if(strlen(tline)>1)
 	{
-	  if(mystrncasecmp(tline,CatString3(MyName, "Back",""),
+	  if(strncasecmp(tline,CatString3(MyName, "Back",""),
 			   Clength+4)==0)
 	    {
 	      CopyString(&BackColor,&tline[Clength+4]);
