@@ -1,5 +1,4 @@
-/* -*-c-*- */
-/* Part of the FvwmTaskBar Module for Fvwm.
+/* Part of the FvwmTaskBar Module for Fvwm. 
  *
  * The functions in this header file were originally part of the GoodStuff
  * and FvwmIdent modules for Fvwm, so there copyrights are listed:
@@ -14,5 +13,7 @@
 
 /* Function Prototypes */
 Pixel GetColor(char *name);
+Pixel GetHilite(Pixel background);
+Pixel GetShadow(Pixel background);
 void nocolor(char *a, char *b);
 
