@@ -125,12 +125,18 @@ int UseSkipList    = False,
     adjust_flag    = False,
     AutoStick      = False,
     AutoHide       = False,
-    HighlightFocus = False;
+    HighlightFocus = False,
+    DeskOnly       = False;
 
 unsigned int ScreenWidth, ScreenHeight;
 
 int NRows, RowHeight, Midline;
 
+#define COUNT_LIMIT    10000
+long DeskNumber;               /* Added by Balaji R */
+int  First = 1;
+int  Count = 0;
+
 /* Imported from Goodies */
 extern int stwin_width, goodies_width;
 extern TipStruct Tip;
@@ -187,7 +193,7 @@ void main(int argc, char **argv)
   SetMessageMask(Fvwm_fd,M_ADD_WINDOW | M_CONFIGURE_WINDOW | M_DESTROY_WINDOW |
 		 M_WINDOW_NAME | M_ICON_NAME | M_RES_NAME | M_DEICONIFY | M_ICONIFY |
 		 M_END_WINDOWLIST | M_FOCUS_CHANGE | M_FUNCTION_END | M_CONFIG_INFO |
-		 M_TITLE_ICON | M_SCROLLREGION);
+		 M_MINI_ICON | M_SCROLLREGION | M_NEW_DESK);
 
   /* Parse the config file */
   InitList(&swallowed);
@@ -304,6 +310,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
   int redraw=-1;
   int i;
   long flags;
+  long Desk;
   char *name,*string;
   Picture p;
   
@@ -342,27 +349,51 @@ void ProcessMessage(unsigned long type,unsigned long *body)
       break;
     }
 
-    if (FindItem(&windows,body[0]) != -1) break;
+    if ((i=FindItem(&windows,body[0])) != -1) {
+      if (GetDeskNumber(&windows,i,&Desk) && DeskOnly) {
+        if (DeskNumber != Desk && DeskNumber == body[7]) {
+          /* window moving to current desktop */
+          AddButton(&buttons, ItemName(&windows,i), GetItemPicture(&windows,i), BUTTON_UP, i);
+          redraw = 1;
+        }
+        if (DeskNumber != body[7] && DeskNumber == Desk) {
+          /* window moving to another desktop */
+          RemoveButton(&buttons, i);
+          redraw = 1;
+        }
+      }
+      UpdateItemFlagsDesk(&windows, body[0], body[8], body[7]);
+      break;
+    }
+
     if (!(body[8] & WINDOWLISTSKIP) || !UseSkipList) {
-      AddItem(&windows, body[0], body[8]);
+      AddItem(&windows, body[0], body[8], body[7], Count++);
+      if (Count > COUNT_LIMIT) Count = 0;
     }
     break;
 
   case M_DESTROY_WINDOW:
-    if ((i = DeleteItem(&windows, body[0])) == -1) break;
+    if ((i = FindItem(&windows, body[0])) == -1) break;
     if (FindItem(&swallowed, body[0]) != -1) break;
-    RemoveButton(&buttons, i);
-    redraw = 1;
+    if (GetDeskNumber(&windows, i, &Desk)) {
+      DeleteItem(&windows, body[0]);
+      if (Desk == DeskNumber || !DeskOnly) {
+        RemoveButton(&buttons, i); /* what about sticky windows? */
+                                   /* problem when they are deleted from another desktop! */
+        redraw = 1;
+      }
+    }
     break;
 
-  case M_TITLE_ICON:
+  case M_MINI_ICON:
     if ((i = FindItem(&windows, body[0])) == -1) break;
+    p.picture = body[1];
+    p.mask    = body[2];
+    p.width   = body[3];
+    p.height  = body[4];
+    p.depth   = body[5];
+    UpdateItemPicture(&windows, i, &p);
     if (UpdateButton(&buttons, i, NULL, DONT_CARE) != -1) {
-      p.picture = body[1];
-      p.mask    = body[2];
-      p.width   = body[3];
-      p.height  = body[4];
-      p.depth   = body[5];
       UpdateButtonPicture(&buttons, i, &p);
       redraw = 0;
     }
@@ -383,8 +414,12 @@ void ProcessMessage(unsigned long type,unsigned long *body)
       break;
     if (UpdateButton(&buttons, i, string, DONT_CARE) == -1)
       {
-      AddButton(&buttons, string, NULL, BUTTON_UP);
-      redraw = 1;
+      if (GetDeskNumber(&windows, i, &Desk) == 0) return; /* ?? */
+      if (!DeskOnly || Desk == DeskNumber)
+        {
+        AddButton(&buttons, string, NULL, BUTTON_UP, i);
+        redraw = 1;
+        }
       }
     else
       redraw = 0;
@@ -427,9 +462,11 @@ void ProcessMessage(unsigned long type,unsigned long *body)
     break;
 
   case M_NEW_DESK:
-    break;
-
-  case M_NEW_PAGE:
+    DeskNumber = body[0];
+    if (!First && DeskOnly)
+      redraw_buttons();
+    else
+      First = 0;
     break;
 
   }
@@ -437,6 +474,22 @@ void ProcessMessage(unsigned long type,unsigned long *body)
   if (redraw >= 0) RedrawWindow(redraw);
 }
 
+void redraw_buttons()
+{
+  Button *temp;
+  Item *item;
+
+  while (buttons.head)
+    RemoveButton(&buttons, buttons.head->count);
+
+  for (item=windows.head; item; item=item->next)
+    if (DeskNumber == item->Desk || (item->flags & STICKY))
+      AddButton(&buttons, item->name, &(item->p), BUTTON_UP, item->count);
+    
+  RedrawWindow(1);
+}
+
+
 /******************************************************************************
   SendFvwmPipe - Send a message back to fvwm 
     Based on SendInfo() from FvwmIdent:
@@ -574,37 +627,39 @@ void ParseConfig(char *file)
   while (tline != (char *)0) {
     while (isspace(*tline))tline++;
     if (strlen(tline)>1 && tline[0] != '#') {
-      if(mystrncasecmp(tline, CatString3(Module, "Font",""),Clength+4)==0)
+      if(strncasecmp(tline, CatString3(Module, "Font",""),Clength+4)==0)
 	CopyString(&font_string,&tline[Clength+4]);
-      else if(mystrncasecmp(tline, CatString3(Module, "SelFont",""),Clength+7)==0)
+      else if(strncasecmp(tline, CatString3(Module, "SelFont",""),Clength+7)==0)
 	CopyString(&selfont_string,&tline[Clength+7]);
-      else if(mystrncasecmp(tline,CatString3(Module,"Fore",""), Clength+4)==0)
+      else if(strncasecmp(tline,CatString3(Module,"Fore",""), Clength+4)==0)
 	CopyString(&ForeColor,&tline[Clength+4]);
-      else if(mystrncasecmp(tline,CatString3(Module, "Geometry",""), Clength+8)==0) {
+      else if(strncasecmp(tline,CatString3(Module, "Geometry",""), Clength+8)==0) {
 	str = &tline[Clength+9];
 	while(((isspace(*str))&&(*str != '\n'))&&(*str != 0))	str++;
 	str[strlen(str)-1] = 0;
 	UpdateString(&geometry,str);
-      } else if(mystrncasecmp(tline,CatString3(Module, "Back",""), Clength+4)==0)
+      } else if(strncasecmp(tline,CatString3(Module, "Back",""), Clength+4)==0)
 	CopyString(&BackColor,&tline[Clength+4]);
-      else if(mystrncasecmp(tline,CatString3(Module, "Action",""), Clength+6)==0)
+      else if(strncasecmp(tline,CatString3(Module, "Action",""), Clength+6)==0)
 	LinkAction(&tline[Clength+6]);
-      else if(mystrncasecmp(tline,CatString3(Module, "UseSkipList",""),
+      else if(strncasecmp(tline,CatString3(Module, "UseSkipList",""),
 			    Clength+11)==0) UseSkipList=True;
-      else if(mystrncasecmp(tline,CatString3(Module, "AutoStick",""),
+      else if(strncasecmp(tline,CatString3(Module, "AutoStick",""),
 			    Clength+9)==0) AutoStick=True;
-      else if(mystrncasecmp(tline,CatString3(Module, "AutoHide",""),
+      else if(strncasecmp(tline,CatString3(Module, "AutoHide",""),
                             Clength+4)==0) { AutoHide=True; AutoStick=True; }
-      else if(mystrncasecmp(tline,CatString3(Module, "UseIconNames",""),
+      else if(strncasecmp(tline,CatString3(Module, "UseIconNames",""),
 			    Clength+12)==0) UseIconNames=True;
-      else if(mystrncasecmp(tline,CatString3(Module, "ShowTransients",""),
+      else if(strncasecmp(tline,CatString3(Module, "ShowTransients",""),
 			    Clength+14)==0) ShowTransients=True;
-      else if(mystrncasecmp(tline,CatString3(Module, "UpdateInterval",""),
+      else if(strncasecmp(tline,CatString3(Module, "DeskOnly",""),
+                            Clength+8)==0) DeskOnly=True;
+      else if(strncasecmp(tline,CatString3(Module, "UpdateInterval",""),
                             Clength+14)==0)
                                UpdateInterval=atoi(&tline[Clength+14]);
-      else if(mystrncasecmp(tline,CatString3(Module, "HighlightFocus",""),
+      else if(strncasecmp(tline,CatString3(Module, "HighlightFocus",""),
                             Clength+14)==0) HighlightFocus=True;
-      else if(mystrncasecmp(tline,CatString3(Module, "SwallowModule",""),
+      else if(strncasecmp(tline,CatString3(Module, "SwallowModule",""),
 			    Clength+13)==0) {
 	
 	/* tell fvwm to launch the module for us */
@@ -628,7 +683,7 @@ void ParseConfig(char *file)
 	  AddItemName(&swallowed, &str[j], F_NOT_SWALLOWED);
 	}	
 	free(str);
-      } else if(mystrncasecmp(tline,CatString3(Module, "Swallow",""),
+      } else if(strncasecmp(tline,CatString3(Module, "Swallow",""),
 			      Clength+7)==0) {
 	
 	/* tell fvwm to Exec the process for us */
@@ -652,11 +707,11 @@ void ParseConfig(char *file)
 	  AddItemName(&swallowed, &str[j], F_NOT_SWALLOWED);
 	}	
 	free(str);
-      } else if(mystrncasecmp(tline,"ButtonWidth",11) == 0) {
+      } else if(strncasecmp(tline,"ButtonWidth",11) == 0) {
 	button_width = atoi(&tline[11]);
-      } else if(mystrncasecmp(tline,"IconPath",8) == 0) {
+      } else if(strncasecmp(tline,"IconPath",8) == 0) {
 	CopyString(&IconPath, &tline[8]);
-      } else if(mystrncasecmp(tline,"PixmapPath",10) == 0) {
+      } else if(strncasecmp(tline,"PixmapPath",10) == 0) {
 	CopyString(&PixmapPath, &tline[10]);
       } else {
 	GoodiesParseConfig(tline, Module);
@@ -816,7 +871,7 @@ void LoopOnEvents()
             y = win_y - ScreenHeight;
           }
           sprintf(tmp,"Popup %s %d %d", StartPopup, x, y);
-          SendFvwmPipe(tmp, ItemID(&windows, num));
+          SendFvwmPipe(tmp, ItemID(&windows, 0));
         } else if (MouseInMail(Event.xbutton.x, Event.xbutton.y)) {
            HandleMailClick(Event);
 	} else {
@@ -981,13 +1036,13 @@ void LinkAction(char *string)
 char *temp;
   temp=string;
   while(isspace(*temp)) temp++;
-  if(mystrncasecmp(temp, "Click1", 6)==0)
+  if(strncasecmp(temp, "Click1", 6)==0)
     CopyString(&ClickAction[0],&temp[6]);
-  else if(mystrncasecmp(temp, "Click2", 6)==0)
+  else if(strncasecmp(temp, "Click2", 6)==0)
     CopyString(&ClickAction[1],&temp[6]);
-  else if(mystrncasecmp(temp, "Click3", 6)==0)
+  else if(strncasecmp(temp, "Click3", 6)==0)
     CopyString(&ClickAction[2],&temp[6]);
-  else if(mystrncasecmp(temp, "Enter", 5)==0)
+  else if(strncasecmp(temp, "Enter", 5)==0)
     CopyString(&EnterAction,&temp[5]);
 }
 
@@ -1364,12 +1419,14 @@ void ConstrainSize (XSizeHints *hints, int *widthp, int *heightp)
 void WarpTaskBar(int y) {
   win_x = win_border;
 
-  if (y < Midline)
-    win_y = win_border;
-  else
-    win_y = (int)ScreenHeight - win_height - win_border;
+  if (!AutoHide) {
+    if (y < Midline)
+      win_y = win_border;
+    else
+      win_y = (int)ScreenHeight - win_height - win_border;
 
-  XMoveWindow(dpy, win, win_x, win_y);
+    XMoveWindow(dpy, win, win_x, win_y);
+  }
   if (AutoHide) SetAlarm(HIDE_TASK_BAR);
 
   /* Prevent oscillations caused by race with 
@@ -1383,29 +1440,45 @@ void WarpTaskBar(int y) {
  RevealTaskBar -- Make taskbar fully visible
  ***********************************************************************/
 void RevealTaskBar() {
+  int new_win_y;
+
   ClearAlarm();
 
-  if (win_y < Midline) 
-    win_y = win_border;
-  else 
-    win_y = (int)ScreenHeight - win_height - win_border;
+  if (win_y < Midline) {
+    new_win_y = win_border;
+    for (; win_y<=new_win_y; win_y+=2)
+      XMoveWindow(dpy, win, win_x, win_y);
+  } else {
+    new_win_y = (int)ScreenHeight - win_height - win_border;
+    for (; win_y>=new_win_y; win_y-=2)
+      XMoveWindow(dpy, win, win_x, win_y);
+  }
 
-  BelayHide = False; 
+  win_y = new_win_y;
   XMoveWindow(dpy, win, win_x, win_y);
+  BelayHide = False; 
 }
 
 /***********************************************************************
  HideTaskbar -- Make taskbar partially visible
  ***********************************************************************/
 void HideTaskBar() {
+  int new_win_y;
+
   ClearAlarm();
 
-  if (win_y < Midline) 
-    win_y = /*1*/ - win_height;
-  else
-    win_y = (int)ScreenHeight /*- 1*/;
+  if (win_y < Midline) {
+    new_win_y = 1 - win_height;
+    for (; win_y>=new_win_y; --win_y)
+      XMoveWindow(dpy, win, win_x, win_y);
+  } else {
+    new_win_y = (int)ScreenHeight - 1;
+    for (; win_y<=new_win_y; ++win_y)
+      XMoveWindow(dpy, win, win_x, win_y);
+  }
 
-  XMoveWindow(dpy, win, win_x, win_y);
+  win_y = new_win_y;
+  /* XMoveWindow(dpy, win, win_x, win_y); */
 }
 
 /***********************************************************************
