@@ -1,5 +1,6 @@
-/* -*-c-*- */
-/* FvwmWinList Module for Fvwm.
+#include <fvwm/fvwmlib.h>
+
+/* FvwmWinList Module for Fvwm. 
  *
  *  Copyright 1994,  Mike Finger (mfinger@mermaid.micro.umn.edu or
  *                               Mike_Finger@atk.com)
@@ -19,19 +20,13 @@
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact. */
 
-#ifndef FVWMWINLIST_H
-#define FVWMWINLIST_H
-
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xproto.h>
-#include <X11/Xatom.h>
-#include <X11/Intrinsic.h>
-#include <X11/cursorfont.h>
-
-#include <libs/fvwmlib.h>
-#include <fvwm/fvwm.h>
-#include <libs/vpacket.h>
+#define STICKY         (1<<2) /* Does window stick to glass? */
+#define ONTOP          (1<<1) /* does window stay on top */
+#define BORDER         (1<<13) /* Is this decorated with border*/
+#define TITLE          (1<<14) /* Is this decorated with title */
+#define ICONIFIED      (1<<16) /* is it an icon now? */
+#define TRANSIENT      (1<<17) /* is it a transient window? */
+#define WINDOWLISTSKIP   (1<<3)
 
 /* Motif  window hints */
 typedef struct
@@ -55,13 +50,13 @@ typedef PropMotifWmHints        PropMwmHints;
 #define MWM_FUNC_MOVE           (1L << 2)
 #define MWM_FUNC_MINIMIZE       (1L << 3)
 #define MWM_FUNC_MAXIMIZE       (1L << 4)
-#define MWM_FUNC_CLOSE          (1L << 5)
+#define MWM_FUNC_CLOSE          (1L << 5)       
 
 /* values for MwmHints.input_mode */
 #define MWM_INPUT_MODELESS                      0
 #define MWM_INPUT_PRIMARY_APPLICATION_MODAL     1
 #define MWM_INPUT_SYSTEM_MODAL                  2
-#define MWM_INPUT_FULL_APPLICATION_MODAL        3
+#define MWM_INPUT_FULL_APPLICATION_MODAL        3         
 
 /* bit definitions for MwmHints.decorations */
 #define MWM_DECOR_ALL                 (1L << 0)
@@ -79,33 +74,39 @@ typedef PropMotifWmHints        PropMwmHints;
 #define DEFMAXWIDTH 10000
 #define DEFMINWIDTH 0
 
-/*
+/*************************************************************************
   Subroutine Prototypes
-*/
-void MainEventLoop(void);
+**************************************************************************/
+void EndLessLoop(void);
 void ReadFvwmPipe(void);
 void ProcessMessage(unsigned long type,unsigned long *body);
-RETSIGTYPE DeadPipe(int nonsense) __attribute__((noreturn));
+void SendFvwmPipe(char *message,unsigned long window);
+void DeadPipe(int nonsense);
 void MakeMeWindow(void);
-void RedrawWindow(Bool force, Bool clear_bg, XEvent *evp);
-void StartMeUp_I(void);
-void StartMeUp_II(void);
-void ShutMeDown(void);
-void ConsoleMessage(const char *fmt,...) __attribute__((format(printf,1,2)));
+void WaitForExpose(void);
+void RedrawWindow(int force);
+void StartMeUp(void);
+void ShutMeDown(int exitstat);
+void ConsoleMessage(char *fmt,...);
 int OpenConsole(void);
 void ParseConfig(void);
-void ParseConfigLine(char *line);
 void LoopOnEvents(void);
-void AdjustWindow(Bool force);
-
-char *makename(const char *string, Bool iconified);
+void AdjustWindow(void);
+char *makename(char *string,long flags);
 void ChangeWindowName(char *str);
 void LinkAction(char *string);
 void AddToSkipList(char *string);
+int InSkipList(char *string);
 void PrintSkipList(void);
 void FvwmNameMessage(long *body);
 void SetMwmHints(unsigned int value,unsigned int funcs,unsigned int input);
 
-int ErrorHandler(Display *d, XErrorEvent *event);
+XErrorHandler ErrorHandler(Display *d, XErrorEvent *event);
 
+#ifdef BROKEN_SUN_HEADERS
+#include "../../fvwm/sun_headers.h"
 #endif
+
+#ifdef NEEDS_ALPHA_HEADER
+#include "../../fvwm/alpha_header.h"
+#endif /* NEEDS_ALPHA_HEADER */
